function [ey_stiff_eff,Webframe_YZ_start,Webframe_YZ_end,Isklasse,Ii_buckling,Ai_buckling,Strakes,za_plate,za_stiff,ZD,zn,ZB,IN,Delta,L,B,T,D,Z_vert,y_plates,z_plates,Csec_size,cum_sum,Stiff_YZ,Csec_YZ_end,Weight,zp_stiff_eff,Girders,Webframe_ID] = Cross_section_func_LNG_PC1_3(Csec_thick,Type_stiff,Stiff_num,Web_thickness)

%-----------------------------------------------------------------------%
%                                                                       %
%                        INPUT INTERPETATION                            %
%                                                                       %
%      READS AND SORTS INPUT FOR CROSS SECTION STRAKES AND WEBFRAME.    %
%      THE CORRECT ARRAYS AND MATRICES ARE CREATED FOR FUTHER           %
%      CALCULATIONS                                                     %
%                                                                       %
%-----------------------------------------------------------------------%


%Stiffener length/web spacing%
Length_stiff = [1.0000 1.1000 1.2000 1.3000 1.4000 1.5000 1.6000 1.7000 1.8000 1.9000 2.0000 2.1000 2.2000 2.3000 2.4000 2.5000 2.6000 2.7000 2.8000 2.9000 3.0000 3.1000 3.2000 3.3000 3.4000 3.5000 3.6000 3.7000 3.8000 3.9000 4.0000];  %[m]
Csec_thick = Csec_thick*10^-1;

%Reading and sorting of input for stiffeners and plates%
Csection = xlsread('Geometry cross section LNG RR Arctic.xlsx');
Csection(isnan(Csection(:,1)),:)=[];
Csec_YZ = Csection(8:size(Csection,1),1:2)*10^-1;       %Y-Z coordinats for half the cross section%
Csec_size = size(Csec_YZ,1);
Csec_YZ_mir = Csec_YZ;                                  %Y-Z coordinats for the entire cross section%
ID = Csection(:,3);                                     %Structural component ID%
ID(isnan(ID(:,1)),:)=[];
Orient = Csection(:,4);                                 %Stiffener and girder orientation%
Orient(isnan(Orient(:,1)),:)=[];                              
Stiff_size = size(Stiff_num,1);
s = zeros(size(Stiff_num,1),1);                         %Stiffener spacing%
Csec_width = zeros(Csec_size/2,1);                      %Strake width%

Main_particulars = Csection(1:7,1);                     %Ship main particulars%
L = Main_particulars(3,1);                              %Length of the ship in [m] defined as the distance on the summer load waterline from the fore side of the stem to the axis of the rudder stock.L shall not be taken less than 96%, and not to be taken greater than 97%, of the extreme length on the summer load waterline. 
B = Main_particulars(1,1);                              %Greatest moulded breadth in [m], measured at the summer waterline 
T = Main_particulars(4,1);                              %Mean moulded draught in [m].
D = Main_particulars(5,1);                              %Moulded depth defined as the vertical distance in [m] from baseline to moulded deck line at the uppermost continous deck measured amidships.  
LOA = Main_particulars(2,1);                            %Length overall [m]%
Delta = Main_particulars(6,1);                          %Displacement [tonn]%
Isklasse = Main_particulars(7,1);                       %Isklasse PC regelverk
                

%Reading and sorting of input for webframe girders%
Webframe_YZ = Csec_YZ;
Webframe_ID = Csection(:,5);
Webframe_ID(isnan(Webframe_ID(:,1)),:)=[];
Webframe_size = size(Webframe_ID,1);
Webframe_YZ_start = zeros(Webframe_size,2);                   
Webframe_YZ_end = zeros(Webframe_size,2);                     


for i = 1:2:Webframe_size*2
    Webframe_YZ_start(i-((i-1)/2),1) = Webframe_YZ(i,1);
    Webframe_YZ_start(i-((i-1)/2),2) = Webframe_YZ(i+1,1);
    Webframe_YZ_end(i-((i-1)/2),1) = Webframe_YZ(i,2);
    Webframe_YZ_end(i-((i-1)/2),2) = Webframe_YZ(i+1,2);
end


%-----------------------------------------------------------------------%
%                                                                       %
%                     CROSS SECTION CALCULATIONS                        %
%                                                                       %
%      INCLUDES ALL NECESSARY CALCULATIONS FOR LOCAL AND GLOBAL         %
%      RULE CHECKS.                                                     %
%                                                                       %
%                                                                       %
%-----------------------------------------------------------------------%


%Mirroring strake YZ-coordinats%
for i = 1:2:Csec_size
    Csec_YZ_mir(i,:) = -1*Csec_YZ(i,:);
end

Csec_YZ_sym = [Csec_YZ_mir Csec_YZ];                    %Mirrored cross section%
Csec_YZ_start = zeros(Csec_size/2,2);                   %Mirrored start YZ-coordinat scross section%
Csec_YZ_end = zeros(Csec_size/2,2);                     %Mirrored end YZ-coordinat scross section%


for i = 1:2:Csec_size
    Csec_YZ_start(i-((i-1)/2),1) = Csec_YZ(i,1);
    Csec_YZ_start(i-((i-1)/2),2) = Csec_YZ(i+1,1);
    Csec_YZ_end(i-((i-1)/2),1) = Csec_YZ(i,2);
    Csec_YZ_end(i-((i-1)/2),2) = Csec_YZ(i+1,2);
end


%Calculating width of strakes%
for i=1:2:size(Csec_YZ_sym)
    if Csec_YZ(i,1) == Csec_YZ(i,2) || Csec_YZ(i+1,1) == Csec_YZ(i+1,2)
        Csec_width(i,1) = abs(Csec_YZ_sym(i,1)-Csec_YZ_sym(i,2));
        Csec_width(i+1,1) = abs(Csec_YZ_sym(i+1,1)-Csec_YZ_sym(i+1,2));
    else 
        Csec_width(i,1) = sqrt((Csec_YZ_sym(i,1)-Csec_YZ_sym(i,2))^2+(Csec_YZ_sym(i+1,1)-Csec_YZ_sym(i+1,2))^2);
    end
end

Csec_width(Csec_width==0) = [];


%Calculating angel of inclined strakes%
Alpha = zeros(Csec_size/2,1);                                                   
for i = 1:2:Csec_size
    if   Csec_YZ(i,1) ~= Csec_YZ(i,2) && Csec_YZ(i+1,1) ~= Csec_YZ(i+1,2)
        Alpha(i-((i-1)/2),1) = asin(abs(Csec_YZ(i+1,1)-Csec_YZ(i+1,2))/Csec_width(i-((i-1)/2)));
    end
end


%Second moment of area for plates about the transverse neutral axis%
Ai = Csec_thick.*Csec_width;            %Cross sectional area for each strake%  
Ai_mir = Ai;

for i=1:size(Ai_mir,1)
    if Csec_YZ_start(i,1) == 0 && Csec_YZ_end(i,1) == 0
         Ai_mir(i,1) = 0;                                                                      
    end
end

Ai_mir(Ai_mir==0)=[];

Ai = [Ai;Ai_mir];
Ii_plates_trans = zeros(Csec_size/2,1);                         %Second moment of area for each component%
zi_plates_trans = zeros(Csec_size/2,1);                         %Each components mass center distance from keel%
y_plates = zeros(Csec_size/2,1);                                %Y-coordinat for each strake at area centre%
z_plates = zeros(Csec_size/2,1);                                %Z-coordinat for each strake at area centre%

for i = 1:2:Csec_size
    if Csec_YZ(i,1) == Csec_YZ(i,2) || Csec_YZ(i+1,1) == Csec_YZ(i+1,2)
        if Csec_YZ(i,1)==Csec_YZ(i,2)               %Searching for vertical elements
                Ii_plates_trans(i-((i-1)/2),1) = (Csec_thick(i-((i-1)/2),1)*Csec_width(i-((i-1)/2),1)^3)/12;
                zi_plates_trans(i-((i-1)/2),1) = Csec_YZ(i+1,1)+(Csec_width(i-((i-1)/2),1)/2);
                z_plates(i-((i-1)/2),1) = (Csec_YZ(i+1,1)+Csec_YZ(i+1,2))/2;
                y_plates(i-((i-1)/2),1) = Csec_YZ(i,1);
        else                                        %Searching for horisontal elements
                Ii_plates_trans(i-((i-1)/2),1) = (Csec_width(i-((i-1)/2),1)*Csec_thick(i-((i-1)/2),1)^3)/12;
                zi_plates_trans(i-((i-1)/2),1) = Csec_YZ(i+1,1)+(Csec_thick(i-((i-1)/2),1)/2);
                z_plates(i-((i-1)/2),1) = Csec_YZ(i+1,1);
                y_plates(i-((i-1)/2),1) = (Csec_YZ(i,1)+Csec_YZ(i,2))/2;
        end
    else                                            %Searching for inclined elements
                Ii_plates_trans(i-((i-1)/2),1) = ((Csec_thick(i-((i-1)/2),1)*Csec_width(i-((i-1)/2),1)^3)/12 + (Csec_width(i-((i-1)/2),1)*Csec_thick(i-((i-1)/2),1)^3)/12)/2 + (((Csec_width(i-((i-1)/2),1)*Csec_thick(i-((i-1)/2),1)^3)/12 - (Csec_thick(i-((i-1)/2),1)*Csec_width(i-((i-1)/2),1)^3)/12)/2)*cos(2*Alpha(i-((i-1)/2),1));
                zi_plates_trans(i-((i-1)/2),1) = (Csec_YZ(i+1,1)+Csec_YZ(i+1,2))/2;
                z_plates(i-((i-1)/2),1) = (Csec_YZ(i+1,1)+Csec_YZ(i+1,2))/2;
                y_plates(i-((i-1)/2),1) = (Csec_YZ(i,1)+Csec_YZ(i,2))/2;
    end
end

zi_plates_trans_mir = zi_plates_trans;
Ii_plates_trans_mir = Ii_plates_trans;

for i=1:size(zi_plates_trans_mir,1)
    if Csec_YZ_start(i,1) == 0 && Csec_YZ_end(i,1) == 0
         zi_plates_trans_mir(i,1) = 0;
         Ii_plates_trans_mir(i,1) = 0;
    end
end

zi_plates_trans_mir(zi_plates_trans_mir==0)=[];
Ii_plates_trans_mir(Ii_plates_trans_mir==0)=[];

zi_plates_trans = [zi_plates_trans;zi_plates_trans_mir];
Ii_plates_trans = [Ii_plates_trans;Ii_plates_trans_mir];

z_plate_trans = sum(Ai.*zi_plates_trans)./sum(Ai);
I_plate_trans = sum(Ii_plates_trans+Ai.*((z_plate_trans-zi_plates_trans).^2));

%Second moment of area for plates about the vertical neutral axis (centre line) is normally not to be less than
Ii_plates_vert = zeros(Csec_size/2,1);                               %Second moment of area for each component%
zi_plates_vert = zeros(Csec_size/2,1);                               %Each components mass center distance from the ship hull side%

for i = 1:2:Csec_size
    if   Csec_YZ(i,1) == Csec_YZ(i,2) || Csec_YZ(i+1,1) == Csec_YZ(i+1,2)
        if Csec_YZ(i,1)==Csec_YZ(i,2)               %Searching for vertical elements                                                                     
                Ii_plates_vert(i-((i-1)/2),1) = (Csec_width(i-((i-1)/2),1)*Csec_thick(i-((i-1)/2),1)^3)/12;
                zi_plates_vert(i-((i-1)/2),1) = Csec_YZ(i,1)+(Csec_thick(i-((i-1)/2),1)/2);
        else                                        %Searching for horisontal elements
                Ii_plates_vert(i-((i-1)/2),1) = (Csec_thick(i-((i-1)/2),1)*Csec_width(i-((i-1)/2),1)^3)/12;
                zi_plates_vert(i-((i-1)/2),1) = Csec_YZ(i,1)+(Csec_width(i-((i-1)/2),1)/2);
        end
    else                                            %Searching for inclined elements

            Ii_plates_vert(i-((i-1)/2),1) = ((Csec_thick(i-((i-1)/2),1)*Csec_width(i-((i-1)/2),1)^3)/12 + (Csec_width(i-((i-1)/2),1)*Csec_thick(i-((i-1)/2),1)^3)/12)/2 - (((Csec_width(i-((i-1)/2),1)*Csec_thick(i-((i-1)/2),1)^3)/12 - (Csec_thick(i-((i-1)/2),1)*Csec_width(i-((i-1)/2),1)^3)/12)/2)*cos(2*Alpha(i-((i-1)/2),1));
            zi_plates_vert(i-((i-1)/2),1) = (Csec_YZ(i,1)+Csec_YZ(i,2))/2;
    end
end

zi_plates_vert_mir = zi_plates_vert;
Ii_plates_vert_mir = Ii_plates_vert;

for i=1:size(zi_plates_vert_mir,1)
    if Csec_YZ_start(i,1) == 0 && Csec_YZ_end(i,1) == 0
         zi_plates_vert_mir(i,1) = 0;
         Ii_plates_vert_mir(i,1) = 0;
    end
end

zi_plates_vert_mir(zi_plates_vert_mir==0)=[];
Ii_plates_vert_mir(Ii_plates_vert_mir==0)=[];

zi_plates_vert = [zi_plates_vert;zi_plates_vert_mir];
Ii_plates_vert = [Ii_plates_vert;Ii_plates_vert_mir];

I_plate_vert = sum(Ii_plates_vert+Ai.*((zi_plates_vert).^2));

%Calcualting stiffener spacing for each strake%
for i=1:size(Csec_width,1)
    if Stiff_num(i)==0
            s(i,1)= 0;
    else    s(i,1) = Csec_width(i,1)./(Stiff_num(i,1)+1);
    end
end


%Defining matrices%
Stiff_YZ = zeros(sum(Stiff_num),2);                             %Stiffener YZ-coordinats matrix% 
Ii_stiff_trans = Stiff_YZ(:,1);
Ii_stiff_vert = Ii_stiff_trans;
cum_sum = cumsum(Stiff_num(:,1));                               %Cumulative matrix for number of stiffeners%
cum_sum = [1;cum_sum];
zi_stiff_a_trans = zeros(Csec_size/2,1);
zi_stiff_b_trans = zi_stiff_a_trans;
zi_stiff_trans = zeros(size(Stiff_YZ,1),1);
zi_stiff_vert = zi_stiff_trans;
zi_stiff_a_vert = zi_stiff_a_trans;
Strakes = zeros(1,22,Csec_size/2);
ey_stiff_eff = zeros(Csec_size/2,1);
Ii_flange = zeros(Csec_size/2,1);
Ii_stiff_eff = zeros(Csec_size/2,1);
zi_stiff_eff = zeros(Csec_size/2,1);
ey_stiff_eff_buckling = zeros(Csec_size/2,1);
Ii_flange_buckling = zeros(Csec_size/2,1);
Ii_stiff_eff_buckling = zeros(Csec_size/2,1);
zi_stiff_eff_buckling = zeros(Csec_size/2,1);
zp_stiff_eff = zeros(Csec_size/2,1);


%Calculating YZ-coordinats for stiffeners on each strake%
for k = 1:Stiff_size
    for i = cum_sum(k,1)+1:cum_sum(k+1,1)
        Stiff_YZ(i,1) = Csec_YZ_start(k,1);
        Stiff_YZ(i,2) = Csec_YZ_start(k,2);
    end
end

if Csec_YZ_start(1,1)==Csec_YZ_end(1,1)
        for i = 1:cum_sum(2,1)
            Stiff_YZ(i,2) = Stiff_YZ(i,2) + s(1,1);
        end
else    for i = 1:cum_sum(2,1)
            Stiff_YZ(i,1) = Stiff_YZ(i,1) + s(1,1);
        end
end

for j = 1:Stiff_size
    if   Csec_YZ_start(j,1)==Csec_YZ_end(j,1) || Csec_YZ_start(j,2)==Csec_YZ_end(j,2)
            if Csec_YZ_start(j,1)==Csec_YZ_end(j,1)     %Searching for vertical elements
                    for i = cum_sum(j,1)+1:cum_sum(j+1,1)
                        Stiff_YZ(i,2) = Stiff_YZ(i,2) + s(j,1)*(i-cum_sum(j,1));
                    end
            else                                        %Searching for horisontal elements
                for i = cum_sum(j,1)+1:cum_sum(j+1,1)
                        Stiff_YZ(i,1) = Stiff_YZ(i,1) + s(j,1)*(i-cum_sum(j,1));
                end
            end
    else                                                %Searching for inclined elements
        if Csec_YZ_start(j,2) < Csec_YZ_end(j,2)
            for i = cum_sum(j,1)+1:cum_sum(j+1,1)
                Stiff_YZ(i,1) = Stiff_YZ(i,1) + s(j,1)*cos(Alpha(j,1))*(i-cum_sum(j,1));
                Stiff_YZ(i,2) = Stiff_YZ(i,2) + s(j,1)*sin(Alpha(j,1))*(i-cum_sum(j,1));
            end
        else
            for i = cum_sum(j,1)+1:cum_sum(j+1,1)
                Stiff_YZ(i,1) = Stiff_YZ(i,1) + s(j,1)*cos(Alpha(j,1))*(i-cum_sum(j,1));
                Stiff_YZ(i,2) = Stiff_YZ(i,2) + s(j,1)*sin(Alpha(j,1)+pi)*(i-cum_sum(j,1));
            end
        end
    end
end


%Mirroring stiffeners YZ-coordinats%
Stiff_YZ_mir = Stiff_YZ;
for i = 1:size(Stiff_YZ,1)
    Stiff_YZ_mir(i,1) = -1*Stiff_YZ(i,1);
end

Stiff_YZ_sym = [Stiff_YZ_mir Stiff_YZ];


%Definition of stiffener details%

%Bulb stiffeners details%
% b_stiff = [120 140 160 160 180 200 220 240 260 280 300 320 340 370 400 430 430]*10^-1;                                                                                              %Height stiffener [cm]
% s_stiff = [6 8 7 9 8 9 10 10 10 11 12 12 12 13 14 15 17]*10^-1;                                                                                                                     %thickness web stiffener [cm]
% c_stiff = [17 19 22 22 25 28 31 34 37 40 43 46 49 53.5 58 62.5 62.5]*10^-1;
% r_stiff = [5 5.5 6 6 7 8 9 10 11 12 13 14 15 16.5 18 19.5 19.5]*10^-1;                                                                                                              %radius between bulb and web 
% A_stiff = [9.31 13.8 14.6 17.8 18.9 23.6 29.0 32.4 36.1 42.6 49.7 54.2 58.8 69.6 81.4 94.1 103];                                                                                    %area [cm^2] of stiffener 
% Iy_stiff = [133 266 373 448 509 941 1400 1860 2477 3330 4460 5530 6760 9470 12930 17260 18860];                                                                                     %Second moment of area [cm^4]
% ey_stiff = [7.2 8.18 9.66 9.36 10.9 12.1 13.4 14.7 16.2 17.4 18.7 20.1 21.5 23.5 25.5 27.4 26.9];                                                                                   %neutral axis to stiffener without plateflange [cm]
% Weight_stiff = [7.31 10.8 11.4 14.0 14.8 18.5 22.8 25.4 28.3 33.5 39 42.5 46.1 54.6 63.9 73.9 80.6];                                                                                %Weight in [kg/m] for stiffener 
% tf_stiff = [14.7 17.7 19.7 22.2 25.5 28.8 32.1 35.4 38.7 42 45.3 48.6 52 56.9 61.9 66.8 66.8]*(10^-1);                                                                              %thickness flange of bulb profile [cm], 
% hfc_stiff = [0 0 0 0 0 188 206 225 244 263 281 300 318 346 374 402 402];                                                                                                            %height of local frame measured to centre of plate flange area [mm]
% bw_stiff = [0 0 0 0 0 10.9 12.1 13.3 14.5 15.8 16.9 18.1 19.3 21.1 22.9 24.7 24.7];                                                                                                 %Distance in [mm], measured in the plane of flange and from the mid thickness of the web to the centre of the flange area, see also fig.18. 

%Flatbar stiffeners details%
b_stiff = [200 200 200 250 250 250 300 300 300 350 350 350 400 400 400 500 500 600 600 700 700 800 800]*10^-1;                                                                      %Height stiffener [cm]
s_stiff = [15 25 35 20 25 35 30 25 35 30 25 35 30 40 35 40 35 40 45 50 55 55 60]*10^-1;                                                                                             %thickness web stiffener [cm]
c_stiff = [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0]*10^-1;                                                                                                                    %
r_stiff = [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 ]*10^-1;                                                                                                                   %radius between bulb and web
A_stiff = [30 50 70 50 62.5 87.5 90 75 105 105 87.5 122.5 120 160 140 200 175 240 270 350 385 440 480];                                                                             %area [cm^2] of stiffener
Iy_stiff = [1000 1666.6 2333.3 2604.1 3255.2 4557.2 6750 5625 7875 10718.75 8932.3 12505.2 16000 21333.3 18666.6 41666.6 36458.3 72000 81000 142916.6 157208.3 234666.6 256000];    %Second moment of area [cm^4]
ey_stiff = [10 10 10 12.5 12.5 12.5 15 15 15 17.5 17.5 17.5 20 20 20 25 25 30 30 35 35 40 40];                                                                                      %neutral axis to stiffener without plateflange [cm]
Weight_stiff = [23.4 39 54.6 39 48.75 68.25 70.2 58.5 81.9 81.9 68.25 95.55 93.6 124.8 109.2 156 136.5 187.2 210.6 273 300.3 343.2 374.4];                                          %Weight in [kg/m] for stiffener
tf_stiff = [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0]*(10^-1);                                                                                                                 %thickness flange of bulb profile [cm],
hfc_stiff = [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0];                                                                                                                        %height of local frame measured to centre of plate flange area [mm]
bw_stiff = [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0];                                                                                                                         %Distance in [mm], measured in the plane of flange and from the mid thickness of the web to the centre of the flange area, see also fig.18.

%Calculating bulb stiffeners distance to the z neutral axis and second moment of area for this axis%
Iz_stiff = zeros(1,size(s_stiff,2));
ez_stiff = zeros(1,size(s_stiff,2));
b_stiffweb = zeros(1,size(s_stiff,2));
bf_stiff = zeros(1,size(s_stiff,2));
Afn_stiff = zeros(1,size(s_stiff,2));

for i=1:size(s_stiff,2)    
    ez_stiff(1,i) = ((((s_stiff(1,i))/2).*(s_stiff(1,i)).*b_stiff(1,i)) + (2*c_stiff(1,i).*r_stiff(1,i).*(s_stiff(1,i)+c_stiff(1,i)./2)))./(b_stiff(1,i).*s_stiff(1,i)+c_stiff(1,i).*2.*r_stiff(1,i));    
    Iz_stiff(1,i) = ((b_stiff(1,i).*s_stiff(1,i).^3 + 2*r_stiff(1,i).*(c_stiff(1,i).^3))/12)+((b_stiff(1,i).*s_stiff(1,i)).*((ez_stiff(1,i)-s_stiff(1,i)/2)^2))+(2*r_stiff(1,i).*c_stiff(1,i).*(s_stiff(1,i)+(c_stiff(1,i)/2)-ez_stiff(1,i))^2);
    b_stiffweb(1,i) = (b_stiff(1,i)-tf_stiff(1,i))*10;          %Heigth of stiffener web in [mm];(formula = b_stiff-thickness of bulb)
    bf_stiff(1,i) = (c_stiff(1,i) + s_stiff(1,i))*10;           %Breadth of flange [mm]

end

for i=1:size(s_stiff,2) 
    Afn_stiff(1,i) = (bf_stiff(1,i)/10)*(tf_stiff(1,i));        %((A_stiff(1,i))) - ((b_stiffweb(1,i)/10)*(s_stiff(1,i)));%Net effective area of flange. [cm^2]
end


%Creating matrices for each type of stiffener%
Stiff_id = zeros(1,15,size(Weight_stiff,2));
for i = 1:size(Weight_stiff,2)
    Stiff_id(:,:,i) = [Iy_stiff(1,i) Iz_stiff(1,i) ey_stiff(1,i) ez_stiff(1,i) A_stiff(1,i) Weight_stiff(1,i) b_stiff(1,i) r_stiff(1,i) s_stiff(1,i) b_stiffweb(1,i) hfc_stiff(1,i) bw_stiff(1,i) Afn_stiff(1,i) bf_stiff(1,i) tf_stiff(1,i)];
end


%Pressure for each strake. Must be changed for each case according to rules%
Pressure = [149 153 157 163 168 156 125 70 51 41 22 15 5 5 5 189 189 189 189 189 159 129 98 25 5 5 152 157 162 169 172 152 119 93 69 49 42 5];

%Creating matrices containing every structural detail per strake%
for i = 1:Csec_size/2
    Strakes(:,:,i) = [ID(i,1) Csec_width(i,1) Csec_thick(i,1) s(i,1) Stiff_id(:,:,Type_stiff(i,1)) Length_stiff(1,21) Orient(i,1) Pressure(1,i)];                       %(input('Stiffener type? '),input('Stiffener length? ')))];
end



%Calculating neutural axis, second moment of area, elastic and plastic section modulus included effective flange% 
Ai_flange = Csec_thick.*s;  %[cm^2]
Ai_flange_buckling = Csec_thick.*s*0.8;     %[cm^2]

for i=1:Csec_size/2
    ey_stiff_eff(i,1) = ((Strakes(:,9,i).*(Strakes(:,11,i)-Strakes(:,7,i)))+(Ai_flange(i,1)*(Strakes(:,11,i)+(Csec_thick(i,1)/2))))./(Ai_flange(i,1)+Strakes(:,9,i));
    ey_stiff_eff_buckling(i,1) = ((Strakes(:,9,i).*(Strakes(:,11,i)-Strakes(:,7,i)))+(Ai_flange_buckling(i,1)*(Strakes(:,11,i)+(Csec_thick(i,1)/2))))./((Ai_flange_buckling(i,1))+Strakes(:,9,i));
    Ii_flange(i,1) = (s(i,1)*Csec_thick(i,1).^3)/12;
    Ii_flange_buckling(i,1) = (s(i,1)*0.8*Csec_thick(i,1).^3)/12;
    zp_stiff_eff(i,1) = (Ai_flange(i,1)*abs(Csec_thick(i,1)-(Csec_thick(i,1)/2)))+(Strakes(:,9,i)*Strakes(:,7,i)); %[cm^3]
end


for i=1:Csec_size/2
    Ii_stiff_eff(i,1) = Ii_flange(i,1) + (Ai_flange(i,1).*((Strakes(:,11,i)+(Csec_thick(i,1)/2))-ey_stiff_eff(i,1)).^2) + Strakes(:,5,i) + (Strakes(:,9,i).*((Strakes(:,11,i)-Strakes(:,7,i))-ey_stiff_eff(i,1)).^2);
    Ii_stiff_eff_buckling(i,1) = Ii_flange_buckling(i,1) + (Ai_flange_buckling(i,1).*((Strakes(:,11,i)+(Csec_thick(i,1)/2))-ey_stiff_eff_buckling(i,1)).^2) + Strakes(:,5,i) + (Strakes(:,9,i).*((Strakes(:,11,i)-Strakes(:,7,i))-ey_stiff_eff_buckling(i,1)).^2);
end
for i=1:Csec_size/2
    zi_stiff_eff(i,1) = Ii_stiff_eff(i,1)./ey_stiff_eff(i,1);
    zi_stiff_eff_buckling(i,1) = Ii_stiff_eff_buckling(i,1)./ey_stiff_eff_buckling(i,1);
end

shape = zp_stiff_eff./zi_stiff_eff;         %Shape factor, defining utilization of stiffeners. The lesser the shape factor is, the more optimized it is with respect to bending%


%Adding elastic section modulus, included effective flange into Strakes matrices
for i = 1:Csec_size/2
    Strakes(:,23,i) = zi_stiff_eff(i,1);
end


%Correction of the plastic neutral axis if the area of the stiffener becomes bigger than the area of the plateflange 

for i=1:Csec_size/2
   %ey_stiff_plastic(i,1) = ((Strakes(:,17,i) + (Strakes(:,13,i)*10)*Strakes(:,14,i) + (Ai_flange(i,1)*100))/(2*(Strakes(:,13,i)*10))); %Corrected plastic neutral axis in [mm]
    ey_stiff_plastic(i,1) = (100*Strakes(:,17,i) + Strakes(1,14,i)*(Strakes(1,13,i)*10) - (s(i,1)*10)*(Strakes(1,3,i)*10))/(2*(Strakes(1,13,i)*10)) ;
end 

for i=1:Csec_size/2
   if Ai_flange(i,1) < Strakes(:,9,i)
       zp_stiff_eff(i,1) = (((Strakes(1,3,i)*10)*(s(i,1)/100))*(ey_stiff_plastic(i,1)+(Strakes(1,3,i)/2)))+(((((Strakes(1,14,i)-ey_stiff_plastic(i,1))^2)+(ey_stiff_plastic(i,1)^2))*Strakes(1,13,i)*10)/2000)+((Strakes(1,17,i)*((Strakes(1,15,i)-ey_stiff_plastic(i,1))))/10); %[cm^3]
   else
       zp_stiff_eff(i,1) = (Ai_flange(i,1)*abs(Csec_thick(i,1)-(Csec_thick(i,1)/2)))+(Strakes(:,9,i)*Strakes(:,7,i)); %section modulus with neutral axis at intersection between plate and web. [cm^3]
   end 
end


%Calculating second moment of area and section modulus for stiffeners in entire cross section%
%Calculating distance from each stiffeners neutral axis to the centre of the ship%
if   Csec_YZ_start(1,1)==Csec_YZ_end(1,1) || Csec_YZ_start(1,2)==Csec_YZ_end(1,2)
    if Csec_YZ_start(1,1)==Csec_YZ_end(1,1) && Csec_YZ_start(1,1) == B/2*100            %Searching for vertical shell elements
        for j = cum_sum(1,1)
            zi_stiff_vert(j,1) = Stiff_YZ(j,1)-Strakes(:,7,1);
        end
    elseif Csec_YZ_start(1,1)==Csec_YZ_end(1,1)                                         %Searching for vertical elements
        for j = cum_sum(1,1)
            zi_stiff_vert(j,1) = Stiff_YZ(j,1)+Strakes(:,7,1);
        end        
    elseif Csec_YZ_start(1,2)==Csec_YZ_end(1,2) && Csec_YZ_start(1,2) == D*100          %Searching for horisontal shell elements                                                                     %Searching for horisontal elements
        for j = cum_sum(1,1)
            zi_stiff_vert(j,1) = Stiff_YZ(j,1);
        end
    elseif Csec_YZ_start(1,2)==Csec_YZ_end(1,2)                                         %Searching for horisontal elements
        for j = cum_sum(1,1)
            zi_stiff_vert(j,1) = Stiff_YZ(j,1);
        end        
    end
else                                                                                    %Searching for inclined elements
    for j = cum_sum(1,1)
        zi_stiff_vert(j,1) = Stiff_YZ(j,1)-Strakes(:,7,1)*sin(Alpha(1,1));
    end
end

for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1) && Csec_YZ_start(i,1) == B/2*100    %Searching for vertical shell elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_vert(j,1) = Stiff_YZ(j,1)-Strakes(:,7,i);
                end
            elseif Csec_YZ_start(i,1)==Csec_YZ_end(i,1)                                 %Searching for vertical elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_vert(j,1) = Stiff_YZ(j,1)+Strakes(:,7,i);
                end                
            elseif Csec_YZ_start(i,2)==Csec_YZ_end(i,2) && Csec_YZ_start(i,2) == D*100  %Searching for horisontal shell elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_vert(j,1) = Stiff_YZ(j,1); 
                end
            elseif  Csec_YZ_start(i,2)==Csec_YZ_end(i,2)                                %Searching for horisontal elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_vert(j,1) = Stiff_YZ(j,1); 
                end                
            end
    else                                                                                %Searching for inclined elements
        for j = cum_sum(i,1)+1:cum_sum(i+1,1)
            zi_stiff_vert(j,1) = Stiff_YZ(j,1)-Strakes(:,7,i)*sin(Alpha(i,1));
        end
    end
end

%Calculating zi_stiff_a_vert = stiffener area
for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = 1
                    zi_stiff_a_vert(1,1) = Strakes(:,9,1);
                end
            else                                            %Searching for horisontal elements
                for j = 1
                    zi_stiff_a_vert(1,1) = Strakes(:,9,1);
                end
            end
    else                                                    %Searching for inclined elements
        for j = 1
                    zi_stiff_a_vert(1,1) = Strakes(:,9,1);
        end
    end
end

for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_a_vert(j,1) = Strakes(:,9,i);
                end
            else                                            %Searching for horisontal elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_a_vert(j,1) = Strakes(:,9,i);
                end
            end
    else                                                    %Searching for inclined elements
        for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_a_vert(j,1) = Strakes(:,9,i);
        end
    end
end

%Distance to the vertical neutral axis is equal to centre line of the ship, due to symmetry
z_stiff_vert = B/2*10^2;


%Calculating the second moment of area for each stiffener, in relation to the vertical neutral axis
for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = 1
                    Ii_stiff_vert(j,1) = Strakes(:,6,1)+Strakes(:,9,1).*((z_stiff_vert-zi_stiff_vert(j,1)).^2);
                end
            else                                            %Searching for horisontal elements
                for j = 1
                    Ii_stiff_vert(j,1) = Strakes(:,5,1)+Strakes(:,9,1).*((z_stiff_vert-zi_stiff_vert(j,1)).^2);
                end
            end
    else                                                    %Searching for inclined elements
        for j = 1
                    Ii_stiff_vert(j,1) = Strakes(:,6,1)+Strakes(:,9,1).*((z_stiff_vert-zi_stiff_vert(j,1)).^2);
        end
    end
end

for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    Ii_stiff_vert(j,1) = Strakes(:,6,i)+Strakes(:,9,i).*((z_stiff_vert-zi_stiff_vert(j,1)).^2);
                end
            else                                            %Searching for horisontal elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    Ii_stiff_vert(j,1) = Strakes(:,5,i)+Strakes(:,9,i).*((z_stiff_vert-zi_stiff_vert(j,1)).^2);
                end
            end
    else                                                    %Searching for inclined elements
        for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    Ii_stiff_vert(j,1) = Strakes(:,6,i)+Strakes(:,9,i).*((z_stiff_vert-zi_stiff_vert(j,1)).^2);
        end
    end
end

%Calculating the global second moment of area for stiffeners in cross section
Ii_stiff_vert = [Ii_stiff_vert;Ii_stiff_vert];
I_stiff_vert = sum(Ii_stiff_vert);


%Calculating distance from each stiffener to the transverse neutral axis to the keel, zi_stiff_trans%
if   Csec_YZ_start(1,1)==Csec_YZ_end(1,1) || Csec_YZ_start(1,2)==Csec_YZ_end(1,2)
    if Csec_YZ_start(1,1)==Csec_YZ_end(1,1) && Csec_YZ_start(1,1) == B/2*100    %Searching for vertical shell elements                 
        for j = cum_sum(1,1)
            zi_stiff_trans(j,1) = Stiff_YZ(j,2);
        end
    elseif Csec_YZ_start(1,1)==Csec_YZ_end(1,1)                                 %Searching for vertical elements
        for j = cum_sum(1,1)
            zi_stiff_trans(j,1) = Stiff_YZ(j,2);
        end        
    elseif Csec_YZ_start(1,2)==Csec_YZ_end(1,2) && Csec_YZ_start(1,2) == D*100  %Searching for horisontal shell elements
        for j = cum_sum(1,1)
            zi_stiff_trans(j,1) = Stiff_YZ(j,2)-Strakes(:,7,1);
        end
    elseif Csec_YZ_start(1,2)==Csec_YZ_end(1,2)                                 %Searching for horisontal elements
        for j = cum_sum(1,1)
            zi_stiff_trans(j,1) = Stiff_YZ(j,2)+Strakes(:,7,1);
        end        
    end
else                                                                            %Searching for inclined elements
    for j = cum_sum(1,1)
        zi_stiff_trans(j,1) = Stiff_YZ(1,2)+Strakes(:,7,1)*cos(Alpha(1,1));
    end
end

for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1) && Csec_YZ_start(i,1) == B/2*100    %Searching for vertical shell elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_trans(j,1) = Stiff_YZ(j,2);
                end
            elseif Csec_YZ_start(i,1)==Csec_YZ_end(i,1)
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_trans(j,1) = Stiff_YZ(j,2);
                end                
            elseif Csec_YZ_start(i,2)==Csec_YZ_end(i,2) && Csec_YZ_start(i,2) == D*100  %Searching for horisontal shell elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_trans(j,1) = Stiff_YZ(j,2)-Strakes(:,7,1);
                end
            elseif Csec_YZ_start(i,2)==Csec_YZ_end(i,2)                                 %Searching for horisontal elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_trans(j,1) = Stiff_YZ(j,2)+Strakes(:,7,i); 
                end
            end
    else                                                                                %Searching for inclined elements
        for j = cum_sum(i,1)+1:cum_sum(i+1,1)
            zi_stiff_trans(j,1) = Stiff_YZ(j,2)+Strakes(:,7,i)*cos(Alpha(i,1));
        end
    end
end

%Calculating zi_stiff_a_trans = stiffener area and zi_stiff_b_trans = stiffener area multiplied with stiffener distance from z=0
for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = 1
                    zi_stiff_a_trans(1,1) = Strakes(:,9,1);
                    zi_stiff_b_trans(1,1) = Strakes(:,9,1).*zi_stiff_trans(j,1);
                end
            else                                            %Searching for horisontal elements
                for j = 1
                    zi_stiff_a_trans(1,1) = Strakes(:,9,1);
                    zi_stiff_b_trans(1,1) = Strakes(:,9,1).*zi_stiff_trans(j,1);
                end
            end
    else                                                    %Searching for inclined elements
        for j = 1
                    zi_stiff_a_trans(1,1) = Strakes(:,9,1);
                    zi_stiff_b_trans(1,1) = Strakes(:,9,1).*zi_stiff_trans(j,1);  
        end
    end
end

for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_a_trans(j,1) = Strakes(:,9,i);
                    zi_stiff_b_trans(j,1) = Strakes(:,9,i).*zi_stiff_trans(j,1);
                end
            else                                            %Searching for horisontal elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_a_trans(j,1) = Strakes(:,9,i);
                    zi_stiff_b_trans(j,1) = Strakes(:,9,i).*zi_stiff_trans(j,1);
                end
            end
    else                                                    %Searching for inclined elements
        for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    zi_stiff_a_trans(j,1) = Strakes(:,9,i);
                    zi_stiff_b_trans(j,1) = Strakes(:,9,i).*zi_stiff_trans(j,1);  
        end
    end
end

%Calculating global transverse neutral axis for stiffeners in cross section
z_stiff_trans = sum(zi_stiff_b_trans,1)/sum(zi_stiff_a_trans,1);


%Calculating the second moment of area for each stiffener, in relation to the transverse neutral axis
for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = 1
                    Ii_stiff_trans(j,1) = Strakes(:,5,1)+Strakes(:,9,1).*((z_stiff_trans-zi_stiff_trans(j,1)).^2);
                end
            else                                            %Searching for horisontal elements
                for j = 1
                    Ii_stiff_trans(j,1) = Strakes(:,6,1)+Strakes(:,9,1).*((z_stiff_trans-zi_stiff_trans(j,1)).^2);
                end
            end
    else                                                    %Searching for inclined elements
        for j = 1
                    Ii_stiff_trans(j,1) = Strakes(:,5,1)+Strakes(:,9,1).*((z_stiff_trans-zi_stiff_trans(j,1)).^2);
        end
    end
end

for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    Ii_stiff_trans(j,1) = Strakes(:,5,i)+Strakes(:,9,i).*((z_stiff_trans-zi_stiff_trans(j,1)).^2);
                end
            else                                            %Searching for horisontal elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    Ii_stiff_trans(j,1) = Strakes(:,6,i)+Strakes(:,9,i).*((z_stiff_trans-zi_stiff_trans(j,1)).^2);
                end
            end
    else                                                    %Searching for inclined elements
        for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    Ii_stiff_trans(j,1) = Strakes(:,5,i)+Strakes(:,9,i).*((z_stiff_trans-zi_stiff_trans(j,1)).^2);
        end
    end
end

%Calculating the global second moment of area for stiffeners, in relation to the transverse neutral axis
Ii_stiff_trans = [Ii_stiff_trans;Ii_stiff_trans];
I_stiff_trans = sum(Ii_stiff_trans);


%Calculating cross section structural specifics%
z_trans = ((sum(zi_stiff_a_trans)*z_stiff_trans)+(sum(Ai)*z_plate_trans))/(sum(Ai)+sum(zi_stiff_a_trans));
IN = I_stiff_trans + I_plate_trans + sum(Ai)*((z_plate_trans-z_trans)^2) + sum(zi_stiff_a_trans)*((z_trans-z_stiff_trans)^2);  %Global second moment of area [cm4]
z_vert = B/2*10^2;
IC = I_stiff_vert + I_plate_vert;                                                           %Global second moment of area [cm4]
Z_vert = IC/z_vert;
ZB = IN/z_trans;                                                                            %Section modulus below neutral axis [cm3]
h0 = abs((z_plates*10^-2)-T);
zn = [z_trans*10^-2 D-z_trans*10^-2];                                                       %Distance to neutral axis, below and above [m]
ZD = IN/(zn(1,2)*10^2);                                                                     %Section modulus above neutral axis [cm3]


%Distance from stiffeners to neutral axis [m]%
za_stiff = zeros(sum(Stiff_num),1);                                                 

for i=1:size(Stiff_YZ,1)
    if (Stiff_YZ(i,2)*(10^-2))<zn(:,1)
        za_stiff(i,1) = Stiff_YZ(i,2)*(10^-2);
    else
        za_stiff(i,1) = D-Stiff_YZ(i,2)*(10^-2);
    end
end

za_stiff(za_stiff < 0) = 0;

%Distance from stiffeners to neutral axis [m]%
za_plate = zeros(Csec_size/2,1);                                                 

for i=1:size(Csec_YZ_start,1)
    if (((((Csec_YZ_end(i,2)-Csec_YZ_start(i,2))/2))+Csec_YZ_start(i,2))*(10^-2))<zn(:,1)
        za_plate(i,1) = (((((Csec_YZ_end(i,2)-Csec_YZ_start(i,2))/2))+Csec_YZ_start(i,2))*(10^-2));
    else
        za_plate(i,1) = (D-(Csec_YZ_end(i,2)*(10^-2)))+((Csec_YZ_end(i,2)-Csec_YZ_start(i,2))/2)*(10^-2);
    end
end

za_plate(za_plate < 0) = 0;

%Changing stiffener spacing from cm to m%
for i=1:Csec_size/2
    Strakes(1,4,i) = Strakes(1,4,i)/100;
end


for i = 1:Stiff_size
    if   Csec_YZ_start(i,1)==Csec_YZ_end(i,1) || Csec_YZ_start(i,2)==Csec_YZ_end(i,2)
            if Csec_YZ_start(i,1)==Csec_YZ_end(i,1)         %Searching for vertical elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    Ai_buckling(j,1) = Ai_flange_buckling(i,1) + Strakes(:,9,i);
                    Ii_buckling(j,1) = Ii_stiff_eff_buckling(i,1);
                end
            else                                            %Searching for horisontal elements
                for j = cum_sum(i,1)+1:cum_sum(i+1,1)
                    Ai_buckling(j,1) = Ai_flange_buckling(i,1) + Strakes(:,9,i);
                    Ii_buckling(j,1) = Ii_stiff_eff_buckling(i,1);
                end
            end
    else                                                    %Searching for inclined elements
        for j = cum_sum(i,1)+1:cum_sum(i+1,1)
            Ai_buckling(j,1) = Ai_flange_buckling(i,1) + Strakes(:,9,i);
            Ii_buckling(j,1) = Ii_stiff_eff_buckling(i,1);
        end
    end
end


%Plot cross section%
xs = [Stiff_YZ_sym(:,1) Stiff_YZ_sym(:,3)];
ys = [Stiff_YZ_sym(:,2) Stiff_YZ_sym(:,4)];
plot(xs,ys,'kx');


for i = 1:size(Csec_YZ_sym,1)/2
    x(i,:) = Csec_YZ_sym(2*i-1,:);
    y(i,:)= Csec_YZ_sym(2*i,:);
    for j = 1:2
        hold on
        plot(x(i,2*j-1:2*j),y(i,2*j-1:2*j),'k.-');
        hold off
    end
end

        
%-----------------------------------------------------------------------%
%                                                                       %                                                                  
%                      WEBFRAMES CALCULATIONS                           %                   
%                                                                       % 
%      EVERYTHING FROM THIS POINT, MUST BE CUSTOMIZED FOR EACH CASE.    %
%      THE METHOD IS SOUND, BUT AS THE STRUCTURE IS CHANGED, THE        %
%      MATRICES WILL HAVE TO BE CHANGED WITH IT.                        %
%                                                                       %
%-----------------------------------------------------------------------%


%Creating matrices for each type of girder%
Girders = zeros(1,7,10); %Girders = [1(Webframe ID) 2(Web height) 3(Web thickness) 4(Section modulus) 5(Flange thickness) 6(Web area) 7(Girder span)]

%Girder dimensions%
frame_dim = zeros(size(Webframe_YZ,1),1);


%Webframe calculations%
for i=1:2:size(Webframe_YZ,1)
    if Webframe_YZ(i,1) == Webframe_YZ(i,2) || Webframe_YZ(i+1,1) == Webframe_YZ(i+1,2)
        frame_dim(i,1) = abs(Webframe_YZ(i,1)-Webframe_YZ(i,2));
        frame_dim(i+1,1) = abs(Webframe_YZ(i+1,1)-Webframe_YZ(i+1,2));
    else
        frame_dim(i,1) = sqrt((Webframe_YZ(i,1)-Webframe_YZ(i,2))^2+(Webframe_YZ(i+1,1)-Webframe_YZ(i+1,2))^2);
    end
end

frame_dim(frame_dim==0) = [];


%Rectangular plate girder (Includes plate girder span and web height)%
for i = 1:size(Webframe_ID,1)
    if  Webframe_ID(i,1) == 1 || Webframe_ID(i,1) == 12
        dim1(i,1) = frame_dim(i,1);
        dim1(dim1==0) = [];
    end
end


%Rectangular plate girder (Includes plate girder span and web height)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 2 || Webframe_ID(i,1) == 12 || Webframe_ID(i,1) == 23
        dim2(i,1) = frame_dim(i,1);
        dim2(dim2==0) = [];
    end
end


%Rectangular plate girder (Includes plate girder span and web height)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 3 || Webframe_ID(i,1) == 23|| Webframe_ID(i,1) == 34
        dim3(i,1) = frame_dim(i,1);
        dim3(dim3==0) = [];
    end
end


%Rectangular girder (Includes girder span)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 4|| Webframe_ID(i,1) == 34 || Webframe_ID(i,1) == 45
        dim4(i,1) = frame_dim(i,1);
        dim4(dim4==0) = [];
    end
end


%Non-Rectangular girder (Includes girder span)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 5 || Webframe_ID(i,1) == 45 || Webframe_ID(i,1) == 56
        dim5(i,1) = frame_dim(i,1);
        dim5(dim5==0) = [];
    end
end

%Rectangular girder (Includes girder span)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 6 || Webframe_ID(i,1) == 56 || Webframe_ID(i,1) == 67
        dim6(i,1) = frame_dim(i,1);
        dim6(dim6==0) = [];
    end
end

%Rectangular girder (Includes girder span)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 7 || Webframe_ID(i,1) == 67 || Webframe_ID(i,1) == 78
        dim7(i,1) = frame_dim(i,1);
        dim7(dim7==0) = [];
    end
end

%Rectangular girder (Includes girder span)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 8 || Webframe_ID(i,1) == 78 || Webframe_ID(i,1) == 89
        dim8(i,1) = frame_dim(i,1);
        dim8(dim8==0) = [];
    end
end

%Rectangular girder (Includes girder span)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 9 || Webframe_ID(i,1) == 89 || Webframe_ID(i,1) == 910
        dim9(i,1) = frame_dim(i,1);
        dim9(dim9==0) = [];
    end
end

%Rectangular girder (Includes girder span)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 10 || Webframe_ID(i,1) == 910 || Webframe_ID(i,1) == 1011
        dim10(i,1) = frame_dim(i,1);
        dim10(dim10==0) = [];
    end
end

%Rectangular girder (Includes girder span)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 11 || Webframe_ID(i,1) == 1011
        dim11(i,1) = frame_dim(i,1);
        dim11(dim11==0) = [];
    end
end


%Non-rectangular plate girder (Adds all coordinates into one matrix)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 5 || Webframe_ID(i,1) == 45 || Webframe_ID(i,1) == 56
        A5(2*i-1,:) = Webframe_YZ_start(i,:);
        A5(2*i,:) = Webframe_YZ_end(i,:);
    end
end

%Removing duplicate coordinates%
A5 = unique(A5,'rows');

%Sorting of coordinates for non rectangular girders%
A5(1,:) = [];
A5([3 4],:) = A5([4 3],:);
A5([4 6],:) = A5([6 4],:);

%Non-rectangular plate girder (Adds all coordinates into one matrix)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 8 || Webframe_ID(i,1) == 78 || Webframe_ID(i,1) == 89
        A8(2*i-1,:) = Webframe_YZ_start(i,:);
        A8(2*i,:) = Webframe_YZ_end(i,:);
    end
end

%Removing duplicate coordinates%
A8 = unique(A8,'rows');

%Sorting of coordinates for non rectangular girders%
A8(1,:) = [];
A8([4 5],:) = A8([5 4],:);
A8([3 5],:) = A8([5 3],:);
A8(5,:) = [A8(1,:)];


%Non-rectangular plate girder (Adds all coordinates into one matrix)%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 9 || Webframe_ID(i,1) == 89 || Webframe_ID(i,1) == 910
        A9(2*i-1,:) = Webframe_YZ_start(i,:);
        A9(2*i,:) = Webframe_YZ_end(i,:);
    end
end

%Removing duplicate coordinates%
A9 = unique(A9,'rows');

%Sorting of coordinates for non rectangular girders%
A9(1,:) = [];
A9([4 5],:) = A9([5 4],:);
A9(6,:) = [A9(1,:)];

%Girder span%
S(1,1) = min(dim1);
S(2,1) = max(dim2);
S(3,1) = max(dim3);
S(4,1) = max(dim4);
%S(5,1) = max(dim5);        %Non-rectangular section
S(6,1) = max(dim6);
S(7,1) = max(dim7);
%S(8,1) = max(dim8);        %Non-rectangular section
%S(9,1) = max(dim9);        %Non-rectangular section
S(10,1) = max(dim10);
S(11,1) = max(dim11);

%Girder height%
h(1,1) = max(dim1);
h(2,1) = min(dim2);
h(3,1) = min(dim3);
h(4,1) = min(dim4);
%h(5,1) = min(dim5);        %Non-rectangular section
h(6,1) = min(dim6);
h(7,1) = min(dim7);
%h(8,1) = min(dim8);        %Non-rectangular section
%h(9,1) = min(dim9);        %Non-rectangular section
h(10,1) = min(dim10);
h(11,1) = min(dim11);

%Girder web area rectangular sections%
for i = 1:size(h,1)
    A(i,1) = S(i,1)*h(i,1);
end

%Girder web area non-rectangular sections%
A(5,1) = trapz(A5(:,1),A5(:,2));
A(8,1) = abs(trapz(A8(:,1),A8(:,2)));
A(9,1) = trapz(A9(:,1),A9(:,2));

%Adding girder details to Girder matrix%
for i = 1:size(Webframe_ID,1)
    if Webframe_ID(i,1) == 1
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 2
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 3
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 4
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 5
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 6
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 7
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 8
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 9
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 10
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);
    elseif Webframe_ID(i,1) == 11
        Girders(1,1,Webframe_ID(i,1)) = Webframe_ID(i,1);        
    end
end

for i = 1:size(Girders,3);
    Girders(1,2,i) = h(i,1);
    Girders(1,3,i) = Web_thickness(i,1)*10^-1;
    Girders(1,6,i) = A(i,1);
    Girders(1,7,i) = S(i,1);    
end


%Plot A2 to confirm that coordinates are interpreted correctly. The coordinates needs to be in the correct order for the area integration to be correct%
%plot(A2(:,1),A2(:,2))

for i = 1:size(Girders,3);
    a(i,1) = Girders(1,7,i)*0.6; %distance between zero bending moments, assumed that the girders in the cross section are fixed since it is attached to a bulkhead in both ends.
end

for i = 1:size(Girders,3);
    if a(i,1)/(Strakes(1,20,1)*100) <= 0 ;      %Using Strakes(1,20,1), since the webframe spaceing is identical for each strake%
        C(i,1) = 0.00;
    elseif (a(i,1)/(Strakes(1,20,1)*100)) > 0.00 && (a(i,1)/(Strakes(1,20,1)*100)) < 1.00;
        C(i,1) = 0.00 + ((0.38-0.00)*((a(i,1)/(Strakes(1,20,1)*100))-0.00)/(1.00-0.00));
        
    elseif a(i,1)/(Strakes(1,20,1)*100) == 1 ;
        C(i,1) = 0.38;
                
    elseif (a(i,1)/(Strakes(1,20,1)*100)) > 1.00 && (a(i,1)/(Strakes(1,20,1)*100)) < 2.00;
        C(i,1) = 0.38 + ((0.67-0.38)*((a(i,1)/(Strakes(1,20,1)*100))-1.00)/(2.00-1.00));
       
    elseif a(i,1)/(Strakes(1,20,1)*100) == 2; 
        C(i,1) = 0.67;
                
    elseif (a(i,1)/(Strakes(1,20,1)*100)) > 2.00 && (a(i,1)/(Strakes(1,20,1)*100)) < 3.00;
        C(i,1) = 0.67 + ((0.84-0.67)*((a(i,1)/(Strakes(1,20,1)*100))-2.00)/(3.00-2.00));
      
    elseif a(i,1)/(Strakes(1,20,1)*100) == 3;
        C(i,1) = 0.84;
             
    elseif (a(i,1)/(Strakes(1,20,1)*100)) > 3.00 && (a(i,1)/(Strakes(1,20,1)*100)) < 4.00;
        C(i,1) = 0.84 + ((0.93-0.84)*((a(i,1)/(Strakes(1,20,1)*100))-3.00)/(4.00-3.00));
                
    elseif a(i,1)/(Strakes(1,20,1)*100) == 4 ;
        C(i,1) = 0.93;
        
    elseif (a(i,1)/(Strakes(1,20,1)*100)) > 4.00 && (a(i,1)/(Strakes(1,20,1)*100)) < 5.00;
        C(i,1) = 0.93 + ((0.97-0.93)*((a(i,1)/(Strakes(1,20,1)*100))-4.00)/(5.00-4.00));        
                
    elseif a(i,1)/(Strakes(1,20,1)*100) == 5;
        C(i,1) = 0.97;
        
    elseif (a(i,1)/(Strakes(1,20,1)*100)) > 5.00 && (a(i,1)/(Strakes(1,20,1)*100)) < 6.00;
        C(i,1) = 0.97 + ((0.99-0.97)*((a(i,1)/(Strakes(1,20,1)*100))-5.00)/(6.00-5.00));        
                 
    elseif a(i,1)/(Strakes(1,20,1)*100) == 6; 
        C(i,1) = 0.99;
        
    elseif (a(i,1)/(Strakes(1,20,1)*100)) > 6.00 && (a(i,1)/(Strakes(1,20,1)*100)) < 7.00;
        C(i,1) = 0.99 + ((1.00-0.99)*((a(i,1)/(Strakes(1,20,1)*100))-6.00)/(7.00-6.00));        

    elseif a(i,1)/(Strakes(1,20,1)*100) >= 7; 
        C(i,1) = 1.00;
    end 
end       



for i=1:Webframe_size
    if Webframe_YZ_start(i,2) == Webframe_YZ_end(i,2)
        if Webframe_ID(i,1) == 1
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 1
                    A_gpfeff(i,1) = Strakes(1,3,i).*((Strakes(1,20,1)*100)*C(j,1)); %Effective plate flange according to page 39 design loads. 
                end
            end
        elseif Webframe_ID(i,1) == 2
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 2
                    A_gpfeff(i,1) = Strakes(1,3,i).*((Strakes(1,20,1)*100)*C(j,1)); %Effective plate flange according to page 39 design loads. 
                end
            end
        elseif Webframe_ID(i,1) == 3
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 3
                    A_gpfeff(i,1) = Strakes(1,3,i).*((Strakes(1,20,1)*100)*C(j,1)); %Effective plate flange according to page 39 design loads. 
                end
            end
        elseif Webframe_ID(i,1) == 4
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 4
                    A_gpfeff(i,1) = Strakes(1,3,i).*((Strakes(1,20,1)*100)*C(j,1)); %Effective plate flange according to page 39 design loads. 
                end
            end
        elseif Webframe_ID(i,1) == 10
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 10
                    A_gpfeff(i,1) = Strakes(1,3,i).*((Strakes(1,20,1)*100)*C(j,1)); %Effective plate flange according to page 39 design loads. 
                end
            end
        elseif Webframe_ID(i,1) == 11
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 11
                    A_gpfeff(i,1) = Strakes(1,3,i).*((Strakes(1,20,1)*100)*C(j,1)); %Effective plate flange according to page 39 design loads. 
                end
            end            
        end
    elseif Webframe_YZ_start(i,1)==Webframe_YZ_end(i,1)
                if Webframe_ID(i,1) == 6
                    for j=1:size(Girders,3)
                        if Girders(1,1,j) == 6
                            A_gpfeff(i,1) = Strakes(1,3,i).*((Strakes(1,20,1)*100)*C(j,1)); %Effective plate flange according to page 39 design loads. 
                        end
                    end
                elseif Webframe_ID(i,1) == 7
                    for j=1:size(Girders,3)
                        if Girders(1,1,j) == 7
                            A_gpfeff(i,1) = Strakes(1,3,i).*((Strakes(1,20,1)*100)*C(j,1)); %Effective plate flange according to page 39 design loads. 
                        end
                    end
                end
    end
end


for i=1:Webframe_size
    if Webframe_YZ_start(i,2) == Webframe_YZ_end(i,2)
        if Webframe_ID(i,1) == 1
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 1
                    ey_gir_eff(i,1) = Girders(1,2,j)/2;
                end
            end
        elseif Webframe_ID(i,1) == 2
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 2
                    ey_gir_eff(i,1) = (A_gpfeff(i,1).*(Strakes(1,3,i)/2) + (Girders(1,2,j).*Girders(1,3,j).*(Strakes(1,3,i)+Girders(1,2,j)/2)) + Girders(1,4,j).*Girders(1,5,j).*(Strakes(1,3,i)+Girders(1,2,j)+(Girders(1,5,j)/2)))./(A_gpfeff(i,1)+(Girders(1,2,j).*Girders(1,3,j))+(Girders(1,4,j).*Girders(1,5,j)));
                end
            end
        elseif Webframe_ID(i,1) == 3
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 3
                    ey_gir_eff(i,1) = (A_gpfeff(i,1).*(Strakes(1,3,i)/2) + (Girders(1,2,j).*Girders(1,3,j).*(Strakes(1,3,i)+Girders(1,2,j)/2)) + Girders(1,4,j).*Girders(1,5,j).*(Strakes(1,3,i)+Girders(1,2,j)+(Girders(1,5,j)/2)))./(A_gpfeff(i,1)+(Girders(1,2,j).*Girders(1,3,j))+(Girders(1,4,j).*Girders(1,5,j)));
                end
            end
        elseif Webframe_ID(i,1) == 4
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 4
                    ey_gir_eff(i,1) = (A_gpfeff(i,1).*(Strakes(1,3,i)/2) + (Girders(1,2,j).*Girders(1,3,j).*(Strakes(1,3,i)+Girders(1,2,j)/2)) + Girders(1,4,j).*Girders(1,5,j).*(Strakes(1,3,i)+Girders(1,2,j)+(Girders(1,5,j)/2)))./(A_gpfeff(i,1)+(Girders(1,2,j).*Girders(1,3,j))+(Girders(1,4,j).*Girders(1,5,j)));
                end
            end
        elseif Webframe_ID(i,1) == 10
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 10
                    ey_gir_eff(i,1) = (A_gpfeff(i,1).*(Strakes(1,3,i)/2) + (Girders(1,2,j).*Girders(1,3,j).*(Strakes(1,3,i)+Girders(1,2,j)/2)) + Girders(1,4,j).*Girders(1,5,j).*(Strakes(1,3,i)+Girders(1,2,j)+(Girders(1,5,j)/2)))./(A_gpfeff(i,1)+(Girders(1,2,j).*Girders(1,3,j))+(Girders(1,4,j).*Girders(1,5,j)));
                end
            end
        elseif Webframe_ID(i,1) == 11
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 11
                    ey_gir_eff(i,1) = (A_gpfeff(i,1).*(Strakes(1,3,i)/2) + (Girders(1,2,j).*Girders(1,3,j).*(Strakes(1,3,i)+Girders(1,2,j)/2)) + Girders(1,4,j).*Girders(1,5,j).*(Strakes(1,3,i)+Girders(1,2,j)+(Girders(1,5,j)/2)))./(A_gpfeff(i,1)+(Girders(1,2,j).*Girders(1,3,j))+(Girders(1,4,j).*Girders(1,5,j)));
                end
            end              
        end
    elseif Webframe_YZ_start(i,1)==Webframe_YZ_end(i,1)
                if Webframe_ID(i,1) == 6
                    for j=1:size(Girders,3)
                        if Girders(1,1,j) == 6
                            ey_gir_eff(i,1) = Girders(1,2,j)/2;% neutral axis to girder. 
                        end
                    end
                elseif Webframe_ID(i,1) == 7
                    for j=1:size(Girders,3)
                        if Girders(1,1,j) == 7
                            ey_gir_eff(i,1) = Girders(1,2,j)/2;% neutral axis to girder. 
                        end
                    end
                end
    end
end



for i=1:Webframe_size
    if Webframe_YZ_start(i,2) == Webframe_YZ_end(i,2)
        if Webframe_ID(i,1) == 1
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 1
                    Ii_gir(i,1) = (2*(((((Strakes(1,20,1)*100)*C(j,1))*(Strakes(1,3,i)^3))/12)+(A_gpfeff(i,1)*((ey_gir_eff(i,1)-(Strakes(1,3,i)/2))^2)))... I0+steiner for plate flange
                                    + ((Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))^3))/12) + Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))*(((ey_gir_eff(i,1)-Strakes(1,3,i))/2)^2) + ((Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))^3))/12)+ Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))*(((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))/2)^2));%I0+steiner for web
                end
            end
        elseif Webframe_ID(i,1) == 2
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 2
                    Ii_gir(i,1) = ((((((Strakes(1,20,1)*100)*C(j,1))*(Strakes(1,3,i)^3))/12)+(A_gpfeff(i,1)*((ey_gir_eff(i,1)-(Strakes(1,3,i)/2))^2)))... 
                                    + ((Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))^3))/12) + Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))*(((ey_gir_eff(i,1)-Strakes(1,3,i))/2)^2) + ((Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))^3))/12)+ Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))*(((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))/2)^2)...I0+steiner for web
                                    + ((Girders(1,4,j)*(Girders(1,5,j))^3)/12)+(Girders(1,4,j)*Girders(1,5,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))+(Girders(1,5,j)/2))));%I0+steiner for girder flange
                end
            end
        elseif Webframe_ID(i,1) == 3
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 3
                    Ii_gir(i,1) = ((((((Strakes(1,20,1)*100)*C(j,1))*(Strakes(1,3,i)^3))/12)+(A_gpfeff(i,1)*((ey_gir_eff(i,1)-(Strakes(1,3,i)/2))^2)))... 
                                    + ((Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))^3))/12) + Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))*(((ey_gir_eff(i,1)-Strakes(1,3,i))/2)^2) + ((Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))^3))/12)+ Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))*(((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))/2)^2)...I0+steiner for web
                                    + ((Girders(1,4,j)*(Girders(1,5,j))^3)/12)+(Girders(1,4,j)*Girders(1,5,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))+(Girders(1,5,j)/2))));%I0+steiner for girder flange
                end
            end
        elseif Webframe_ID(i,1) == 4
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 4
                    Ii_gir(i,1) = ((((((Strakes(1,20,1)*100)*C(j,1))*(Strakes(1,3,i)^3))/12)+(A_gpfeff(i,1)*((ey_gir_eff(i,1)-(Strakes(1,3,i)/2))^2)))... 
                                    + ((Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))^3))/12) + Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))*(((ey_gir_eff(i,1)-Strakes(1,3,i))/2)^2) + ((Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))^3))/12)+ Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))*(((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))/2)^2)...I0+steiner for web
                                    + ((Girders(1,4,j)*(Girders(1,5,j))^3)/12)+(Girders(1,4,j)*Girders(1,5,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))+(Girders(1,5,j)/2))));%I0+steiner for girder flange
                end
            end
        elseif Webframe_ID(i,1) == 10
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 10
                    Ii_gir(i,1) = ((((((Strakes(1,20,1)*100)*C(j,1))*(Strakes(1,3,i)^3))/12)+(A_gpfeff(i,1)*((ey_gir_eff(i,1)-(Strakes(1,3,i)/2))^2)))... 
                                    + ((Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))^3))/12) + Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))*(((ey_gir_eff(i,1)-Strakes(1,3,i))/2)^2) + ((Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))^3))/12)+ Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))*(((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))/2)^2)...I0+steiner for web
                                    + ((Girders(1,4,j)*(Girders(1,5,j))^3)/12)+(Girders(1,4,j)*Girders(1,5,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))+(Girders(1,5,j)/2))));%I0+steiner for girder flange
                end
            end
        elseif Webframe_ID(i,1) == 11
            for j=1:size(Girders,3)
                if Girders(1,1,j) == 11
                    Ii_gir(i,1) = ((((((Strakes(1,20,1)*100)*C(j,1))*(Strakes(1,3,i)^3))/12)+(A_gpfeff(i,1)*((ey_gir_eff(i,1)-(Strakes(1,3,i)/2))^2)))... 
                                    + ((Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))^3))/12) + Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))*(((ey_gir_eff(i,1)-Strakes(1,3,i))/2)^2) + ((Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))^3))/12)+ Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))*(((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))/2)^2)...I0+steiner for web
                                    + ((Girders(1,4,j)*(Girders(1,5,j))^3)/12)+(Girders(1,4,j)*Girders(1,5,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))+(Girders(1,5,j)/2))));%I0+steiner for girder flange
                end
            end            
        end
    elseif Webframe_YZ_start(i,1)==Webframe_YZ_end(i,1)
                if Webframe_ID(i,1) == 6
                    for j=1:size(Girders,3)
                        if Girders(1,1,j) == 6
                            Ii_gir(i,1) = (2*(((((Strakes(1,20,1)*100)*C(j,1))*(Strakes(1,3,i)^3))/12)+(A_gpfeff(i,1)*((ey_gir_eff(i,1)-(Strakes(1,3,i)/2))^2)))... I0+steiner for plate flange
                                              + ((Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))^3))/12) + Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))*(((ey_gir_eff(i,1)-Strakes(1,3,i))/2)^2) + ((Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))^3))/12)+ Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))*(((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))/2)^2));%I0+steiner for web
                        end
                    end
                elseif Webframe_ID(i,1) == 7
                    for j=1:size(Girders,3)
                        if Girders(1,1,j) == 7
                            Ii_gir(i,1) = (2*(((((Strakes(1,20,1)*100)*C(j,1))*(Strakes(1,3,i)^3))/12)+(A_gpfeff(i,1)*((ey_gir_eff(i,1)-(Strakes(1,3,i)/2))^2)))... I0+steiner for plate flange
                                              + ((Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))^3))/12) + Girders(1,3,j)*(ey_gir_eff(i,1)-Strakes(1,3,i))*(((ey_gir_eff(i,1)-Strakes(1,3,i))/2)^2) + ((Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))^3))/12)+ Girders(1,3,j)*((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))*(((Girders(1,2,j)+Strakes(1,3,i)-ey_gir_eff(i,1))/2)^2));%I0+steiner for web
                        end
                    end
                end
    end
end

%Section modulus for webgrame sections%
for i=1:size(Ii_gir,1)
    Z_gir(i,1) = Ii_gir(i,1)/ey_gir_eff(i,1);
end

for i=1:size(Ii_gir,1)
    if Webframe_YZ_start(i,2) == Webframe_YZ_end(i,2)
        if Webframe_YZ_start(i,2) == 0 || Webframe_YZ_start(i,2) == 3390
        else
            Z_gir(i,1) = NaN;          
        end
    elseif Webframe_YZ_start(i,1) == Webframe_YZ_end(i,1)
        if Webframe_YZ_start(i,1) == B/2*100
        else
            Z_gir(i,1) = NaN;
        end
    end
end

for i=1:size(Ii_gir,1)
    if Webframe_YZ_start(i,2) == Webframe_YZ_end(i,2)
        if Webframe_YZ_start(i,2) == 0 || Webframe_YZ_start(i,2) == 3390
            if Webframe_ID(i,1)==1
                Girders(1,4,Webframe_ID(i,1))=Z_gir(i,1);
            elseif Webframe_ID(i,1) == 2
                Girders(1,4,Webframe_ID(i,1))=Z_gir(i,1);
            elseif Webframe_ID(i,1) == 3
                Girders(1,4,Webframe_ID(i,1))=Z_gir(i,1);
            elseif Webframe_ID(i,1) == 4
                Girders(1,4,Webframe_ID(i,1))=Z_gir(i,1);
            elseif Webframe_ID(i,1) == 10
                Girders(1,4,Webframe_ID(i,1))=Z_gir(i,1);
            elseif Webframe_ID(i,1) == 11
                Girders(1,4,Webframe_ID(i,1))=Z_gir(i,1);
            end
        end
    elseif Webframe_YZ_start(i,1) == Webframe_YZ_end(i,1)
        if Webframe_YZ_start(i,1) == B/2*100
            if Webframe_ID(i,1) == 6
                Girders(1,4,Webframe_ID(i,1))=Z_gir(i,1);
            elseif Webframe_ID(i,1) == 7
                Girders(1,4,Webframe_ID(i,1))=Z_gir(i,1);
            end
        end
    end
end

%-----------------------------------------------------------------------%
%                                                                       %
%                         WEIGHT ESTIMATE                               %
%                                                                       %
%      CREATES THE WEIGHT OUTPUT WHICH IS USED AS THE OBJECTIVE IN      %
%      THE particle_fun.m FILE                                          %
%                                                                       %
%                                                                       %
%-----------------------------------------------------------------------%

%Weight estimate%
Weight_girder = (sum(Girders(1,6,:).*Girders(1,3,:))*7.8*10^-3)/Strakes(1,20,1); %weight of girder, excluded plateflange since it has been accounted for before. 
Weight_stiffeners = zeros(sum(Stiff_num),1);
Weight_stiffeners(1,1) = Strakes(1,10,1);

for i = 1:Csec_size/2
    for j = cum_sum(i,1)+1:cum_sum(i+1,1)
        Weight_stiffeners(j,1) = Strakes(1,10,i);
    end
end

Weight_plates = Ai*0.7800;              %Divided by 10 000 to converte from cm2 to m2
Weight = sum(Weight_stiffeners)+sum(Weight_plates)+Weight_girder;



