function [best_f,best_x,best_g,history_f,history_x,history_g,iterations,...
          particle,particle_history,t_history] = PSO(fun,counter_number,Feasible_Set,LowerB,...
                                                 UpperB,Algorithm,Init_Popu)

% PSO-parameter.
swarm_size = Algorithm(1);
feasibles_initial_population = Algorithm(2);
generations = Algorithm(3);             
inertia = Algorithm(4);                 
beta = Algorithm(5);                    
beta_k = Algorithm(6);                   
penalty_factor = Algorithm(7);          
print_results = Algorithm(8);           
c1 = 2;                                 
c2 = 2;                                 

% CPU-time at beginning.
t0 = cputime;

% Number of analysis.
particle = 0;

% No of discrete variables
if isempty(Feasible_Set)==1
    discrete_var_number = 0;
else
    discrete_var_number = length(Feasible_Set(:,1));
end

% Generate automatically the initial population randomly so that it
% contains desired amount of feasible particletion
if isempty(Init_Popu)==1
    [position,objective_function,constraint,particle,history_best_f,best_individual,...
        history_f,best_current_individual,history_g] = ...
        new_population(fun,swarm_size,(counter_number+discrete_var_number),feasibles_initial_population,...
        Feasible_Set,penalty_factor,counter_number,LowerB,UpperB);

% Read init pop from file.
else        
    [position,objective_function,constraint,particle,history_best_f,best_individual,...
        history_f,best_current_individual,history_g] = ...
        read_population(fun,Init_Popu,particle,swarm_size,...
        (counter_number+discrete_var_number),feasibles_initial_population,Feasible_Set,penalty_factor);
end

% I pop objective and constraint values.  
f = objective_function;
g = constraint;

% Best global position (feasible or infeasible) and objective function
% value
best_glob = best_individual;
best_glob_f = history_best_f;

% Best global position (feasible) and objective function
% value and constraints.
best_glob_current_f = history_f;
best_glob_current = best_current_individual;
best_glob_current_g = history_g;

% Each particals best position equals the intial position. 
best_location = position;

% Calculate penaliest objective function values  
penalized_f = lower_penalized(f,g,penalty_factor);

% Each particals best known position equals initial position
best_location_f = penalized_f;

% Calculate max speed
if counter_number > 0
    for i = 1:counter_number
        v_min(i) = LowerB(i);
        v_max(i) = UpperB(i);
        maximum_v(i) = 0.3*(v_max(i)-v_min(i));
    end
end
if discrete_var_number > 0
    for i = (counter_number+1):(counter_number+discrete_var_number)
        v_min(i) = Feasible_Set(i-counter_number,1);
        v_max(i) = max(Feasible_Set(i-counter_number,:));
        maximum_v(i) = rounding(0.3*(v_max(i)-v_min(i)),Feasible_Set(i-counter_number,:));
    end
end

% Set 0 as init speed.
velocity = zeros((counter_number+discrete_var_number),swarm_size);

% Round calculator, size calculator and intertia calculator=1
round_counter = 1;
size_counter = 1;
inertia_counter = 1;


% Loop
while round_counter <= generations
    
    % Lets make intertia smaller, if best feasible objective function value has not improved during certain amount of cycles 
    if inertia_counter > beta_k
        inertia = beta*inertia;
        inertia_counter = 1;
    end
        
    % Best feasible particletion number of analysis and store the time
    history_f(round_counter) = best_glob_current_f;
    particle_history(round_counter) = particle;
    t_history(round_counter) = cputime-t0;
    
    
    % Print to the screen the progress of calculation
    disp(['Iter.:' sprintf('%4i',round_counter) ' /' sprintf('%4i',generations) ...
        '  Obj.: ' sprintf('%8.2f',best_glob_current_f) '  Analysis: ' sprintf('%4i',particle) ...
        '  Inert.: ' sprintf('%2.4f',inertia)...
        '  Feasibles: ' sprintf('%4i',feasibles_initial_population) ' /' sprintf('%3i',swarm_size)])    
     
    
    % Speed and position for each particle
    for i=1:swarm_size
        % randomized r1 and r2.
        r1 = rand;
        r2 = rand;
     
        % calculate new speed per particle
        new_velocity(:,i) = inertia*velocity(:,i) + c1*r1*(best_location(:,i) - ...
            position(:,i)) + c2*r2*(best_glob_current - position(:,i));
        
        % Is the maximum speed exeeded?
        for j = 1:(counter_number+discrete_var_number)
            if new_velocity(j,i) > maximum_v(j)
                new_velocity(j,i) = maximum_v(j);
           elseif new_velocity(j,i) < -maximum_v(j)
                new_velocity(j,i) = -maximum_v(j);
            end
        end
                    
        % Calculate new position for particle
        new_position(:,i) = position(:,i) + new_velocity(:,i);
        
        % Did we exceed upper and lower boundaries
        for j = 1:counter_number
            if new_position(j,i) < LowerB(j)
                new_position(j,i) = LowerB(j);
            end
            if new_position(j,i) > UpperB(j)
                new_position(j,i) = UpperB(j);
            end            
        end
        
        % Standardisation of discrete variables
        for j = (counter_number+1):(counter_number+discrete_var_number)
            new_position(j,i) = rounding(new_position(j,i),Feasible_Set(j-counter_number,:));
        end
    end
       
    % Update position and speed
    position = new_position;
    new_position = [];
    velocity = new_velocity;
    new_velocity = [];
  
    % Calc objective and constraints for all particals in new positions
    f = [];
    g = [];
    for i=1:swarm_size 
        % Objective fct and constraints
        [new_f,new_g] = feval(fun,position(:,i));
 
        % Make number of analysis one higher
        particle = particle+1;
      
        f(i) = new_f;
        g(:,i) = new_g;
    end
    
    % Calc penalyzed objective fct
    penalized_f = lower_penalized(f,g,penalty_factor);

    % Set no of feasible particles to 0
    feasibles_initial_population = 0;
    
    % Update the best position and value of each particle in memory
    % global best position and value and best feasible position and value
    % plus constraint values
    for i=1:swarm_size
        % check if best known value is improved
        if penalized_f(i) < best_location_f(i)
            best_location_f(i) = penalized_f(i);
            best_location(:,i) = position(:,i);
        end

        % check if best global value is improved
        if penalized_f(i) < best_glob_f
            best_glob_f = penalized_f(i);
            best_glob = position(:,i);
        end
        
        % check if best global feasible value is improved
        if penalized_f(i) < best_glob_current_f & all(g(:,i)<=0)
            best_glob_current_f = penalized_f(i);
 
            best_glob_current = position(:,i);
            best_glob_current_g = g(:,i);
        end
        
        % record the number of feasible particles.
        if all(g(:,i)<=0)==1
            feasibles_initial_population = feasibles_initial_population+1;
        end
    end
   
    % safe the best known and feasible value
    if isempty(best_glob_current_g) == 1
        history_x = [];
        history_g = [];
    else
        history_x(:,round_counter) = best_glob_current;
        history_g(:,round_counter) = best_glob_current_g;
    end
    history_best_f(round_counter) = best_glob_f;
        
    
    % check if size and inertia calculators should equal to 1
    if round_counter>2 & history_f(round_counter)<history_f(round_counter-1)
         inertia_counter = 1;
         size_counter = 1;
    else
         inertia_counter = inertia_counter+1;
         size_counter = size_counter+1;
    end
    
    % increase round calc by 1
    round_counter = round_counter+1;

end

% no of calculation rounds
iterations = round_counter-1;


% return best feasible particletion
best_f = history_f(iterations);
best_x = best_glob_current;
best_g = best_glob_current_g;


% print graphs if requested
if print_results==1
    figure;
    plot([1:round_counter-1],history_best_f,[1:round_counter-1],history_f)
    legend('Best known','best feasible')
    grid on;
    ylabel('Objective function')
    xlabel('No of Iterations')

    figure;
    plot(particle_history,history_best_f,particle_history,history_f)
    legend('Best known','best feasible')
    grid on;
    ylabel('Objective function')
    xlabel('Analysis')
    
    figure;
    hold on;
    for i=1:length(history_g(:,1))
        plot([1:round_counter-1],history_g(i,:));
    end
    title('Development of Constraints.');
    xlabel('Iteration');
end




